#
# spec file for package procmeter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           procmeter
Version:        3.6+svn415
Release:        3.4
Summary:        Utility to display current system parameters
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            https://gedanken.org.uk/software/procmeter3
Source:         procmeter3-%{version}.tar.xz
Source1:        procmeter3.desktop
# PATCH-FIX-UPSTREAM procmeter3-loff_t.patch
Patch0:         procmeter3-loff_t.patch
# PATCH-FIX-UPSTREAM boo#1102408
Patch1:         procmeter-avoid-build-race.patch
BuildRequires:  libsensors4-devel
BuildRequires:  update-desktop-files
Provides:       procmtr
Obsoletes:      procmtr
%if 0%{?favor_gtk2}
BuildRequires:  gtk2-devel
%else
BuildRequires:  gtk3-devel
%endif
BuildRequires:  libX11-devel
BuildRequires:  libXaw-devel
BuildRequires:  libXt-devel

%description
With procmeter, one can display various system parameters, e.g.
processor load, network load, etc.

%package devel
Summary:        Development files for the procmeter system parameter display program
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
With procmeter, one can display various system parameters, e.g.
processor load, network load, etc.

This package provides files needed to build modules for procmeter.

%prep
%autosetup -n procmeter3-%{version} -p1

%build
make %{?_smp_mflags} INSTDIR=%{_prefix} CFLAGS="%{optflags}"

%install
%make_install INSTDIR=%{_prefix}
%suse_update_desktop_file -i procmeter3 System Monitor

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%license COPYING
%doc NEWS README
%{_datadir}/applications/*.desktop
%{_bindir}/*
%{_prefix}/lib/ProcMeter3/
%{_mandir}/man?/*
%exclude %{_prefix}/lib/ProcMeter3/example/

%files devel
%{_includedir}/ProcMeter3/
%{_prefix}/lib/ProcMeter3/example/

%changelog
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Wed Jul 12 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add procmeter-avoid-build-race.patch to make
  package build reproducible (boo#1102408)
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to latest svn version 3.6+svn415:
  + Allow displaying devices that are mounted from tmpfs (refactor
    code to simplify).
  + Update version numbers, delete CVS headers from files that have
    been changed in the last couple of years.
  + Fix bug with reading ACPI version number string and grammatical
    error in associated warning message.
  + Change variable type to avoid crash (something to do with
    32-bit / 64-bit incompatibility?).
  + Change acceptable versions of libsensors library to either v4
    or v5.
  + Change parameter type since the original typename no longer
    seems valid.
* Mon Sep  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon May 13 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Unbreak description grammar.
* Fri May 10 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to latest svn version (3.6+svn409)
  Bug fixes
  * Fix compilation warnings reported by gcc-7 (string
    overflows).
  * Hide compilation warnings about deprecated GTK-3 API
    functions.
  * Fix compilation warnings about Linux kernel 'major' and
    'minor' macros.
  Module bug fixes
  * The df module should now handle very big disks on 32-bit
    systems.
  * The battery module should work better if
    /sys/class/power_supply doesn't exist.
  * The battery module should work if ACPI records energy rather
    than charge.
  * The battery module works correctly if discharge current is
    negative.
  * The battery module checks that remaining time using current
    or energy will work.
  * The meminfo module handles very long /proc/meminfo (fixes
    Debian bug #747627).
  * The netdev module uses 64-bits to record network traffic.
  * The cpuinfo module doesn't add outputs if the CPUs don't
    report their speed.
  * The cpuinfo module now uses /sys/devices/system/cpu/cpufreq
    not /proc/cpuinfo.
  * The biff module now handles maildir mailboxes (must set
    options variable).
- Added _service file
- Added procmeter3-loff_t.patch (courtesy of Debian)
- Spec cleanup
* Tue Feb 21 2012 dimstar@opensuse.org
- Add libX11-devel, libXaw-devel and libXt-devel BuildRequires on
  openSUSE > 12.1 to cater for the reorganization of xorg-x11
  packages.
* Mon Jan 23 2012 vuntz@opensuse.org
- Update to version 3.6:
  + New features
  - Added GTK3 version.
  - Draw line in foreground colour between outputs in
    procmeter3-gtk2.
  + New modules
  - Battery - new /sys/class/power_supply/ battery information.
  + Bug Fixes
  - Don't package up unused LSM and ANNOUNCE files.
  - Add "-lX11" to LDFLAGS (deb#556073).
  - Move installed modules into /usr/lib/ProcMeter3 (deb#651145).
  - Don't always install the procmeterrc.install file
    (deb#651149).
  - Install procmeter.h to /usr/include/ProcMeter3 (deb#651150).
  - Fix Makefiles to stop linking executables each time make is
    run.
  - Don't crash procmeter3-xaw if specified font doesn't exist.
  + Module bug fixes
  - Changed wireless module to remove kernel 2.4.x code.
  - Fixed stat-intr module to not use data from freed memory.
- Changes from version 3.5d:
  + New features
  - Added an option to limit the number of interrupts listed.
  - Allow installation of stripped executables.
  + Bug Fixes
  - Remove gcc-4.4 compilation warnings.
  - Make error messages consistent.
  - Fix several errors in manual pages.
  - Don't crash if /proc/interrupts has very long lines.
- Drop procmeter-as-needed.patch: fixed upstream.
- Drop procmeter3-3.4a.patch: part of the fixes are upstream, and
  the remaining things are fixed by setting the INSTDIR and CFLAGS
  environment variables when calling make.
- Use favor_gtk2 to switch between gtk2 and gtk3 builds:
  + Use gtk3-devel BuildRequires instead of gtk2-devel for gtk3
    builds.
- Create a devel subpackage for development files.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.5c:
  + New features:
  - Sort the module menu into alphabetical order.
  + New modules:
  - FanSpeed, Temperature & Voltage: Improved hardware sensors.
  + Bug Fixes:
  - Remove 64-bit compilation warnings and fix variable type
    mismatch.
  - Fixed df module to handle disks bigger than 2TB.
  - Fixed sensors module to handle new directory format.
  - Pass top-level Makefile variables down to sub directories.
- Add procmeter-as-needed.patch: fix build with -Wl,--as-needed.
  Taken from Debian.
- Add libsensors4-devel BuildRequires to build the new sensors.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
* Tue Dec 29 2009 vuntz@opensuse.org
- Update to version 3.5b:
  + New Features
  - Extended Window Manager Hints can be specified with a -w
    option.
  - Increase the number of interrupts possible in stat-intr.
  + Bug Fixes
  - Be more careful looking for modules (check '.' and '..').
  - Set the locale to "C" to avoid problems parsing numbers.
  - Ensure that graph-min and graph-max options are used
    properly.
  - Extended the line buffer size for parsing /proc/interrupts.
  - Remove fixed size line buffers in modules (realloc more space
    as needed).
  - Allow LCD version to specify priority as a string or numeric
    value.
- Changes from version 3.5a:
  + Bug Fixes
  - Stop the GTK2 version crashing when displayed items are
    removed.
  - Make sure that the right mouse button menu works with no
    outputs displayed.
  - Make the GTK1 and GTK2 version windows resize themselves like
    Xaw version.
  - Updates to manual pages to reflect new executable names.
  - Bug fixes for ACPI module.
- Changes from version 3.5:
  + New features
  - Added a gtk2 version of ProcMeter3.
  - Renamed the executables but added backwards compatibility
    links.
  - Added DESTDIR option to Makefiles.
- Changes from version 3.4g:
  + Bug fixes:
  - Quicker default update of the date displays (useful after
    suspending).
  - Uptime now accurately shows system running time even after
    suspend.
  - Fix ACPI battery discharge rates.
  - Fix for crashes with stat-cpu outputs on multi-CPU machines.
  - Change to use longer integer values for netdev outputs.
  - Search other places for hardware sensors information.
- Changes from version 3.4f:
  + Bug fixes:
  - The biff module re-reads the inbox if the size or timestamp
    change.
  - The df module uses longer strings for reading from
    /proc/mounts.
- Changes from version 3.4e:
  + New or changed modules:
  - Add in the new CPU statistics (iowait, irq, softirq and
    steal).
  - Add in a display of the CPU clock speed.
  + Bug fixes:
  - Fix some spelling mistakes in the manual pages.
  - Change the default scaling for the DiskUsage outputs to 5
    grid lines of 20%%.
  - Fix some gcc-4.x compilation warnings.
  - Fix some ACPI module bugs.
- Changes from version 3.4d:
  + Bug fixes:
  - Updated ACPI support to handle kernel version 2.6.
  - Added support for /dev/mapper in disk statistics.
  - Change to using 64-bit variables from /proc/stat.
- Changes from version 3.4c:
  + Bug fixes:
  - Make grid-max option work for GTK version.
  - Handle kernel 2.6.x better for hardware sensors.
- Changes from version 3.4b:
  + New or changed modules:
  - Handle different header line for hostap wireless driver.
  + Bug fixes:
  - Modules that didn't work with kernel 2.6.x now do.
  - Improved some module initialisation functions.
- Replace gtk-devel BuildRequires with gtk2-devel.
- Update procmeter3-3.4a.patch: some parts were upstreamed.
- Drop procmeter3-3.4a-array.patch: fixed upstream.
- Drop procmeter3-3.4a-ia64.patch: not needed anymore.
- Remove AutoReqProv: it's default now.
- Use makeinstall macro.
* Thu Aug 17 2006 ro@suse.de
- move from /usr/X11R6 to /usr
* Thu Feb 23 2006 pnemec@suse.cz
- fixed ArrayOutOfBound  #152045
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Wed Jul  9 2003 ltinkl@suse.cz
- updated sources to version 3.4a
* Mon Feb 17 2003 vbobek@suse.cz
-updated to version 3.4
  * new output format
  * added manpage for modules
  * bug fixes
* Thu Oct 10 2002 prehak@suse.cz
- updated to version 3.3b
* Mon Jan 21 2002 cihlar@suse.cz
- use %%{_lib}
* Thu Jul 26 2001 cihlar@suse.cz
- update to version 3.3a
* Mon May 21 2001 cihlar@suse.cz
- fixed cast warnings on ia64
- fixed includes
* Wed Mar  7 2001 cihlar@suse.cz
- updated to version 3.3
* Tue Nov 14 2000 cihlar@suse.cz
- renamed procmtr -> procmeter
- update to version 3.2a
- bzipped sources
- fixed copyright tag
* Wed May 17 2000 cihlar@suse.cz
- Group sorted
* Fri Apr  7 2000 cihlar@suse.cz
- added BuildRoot
- upgrade to version 3.2
* Tue Jan 25 2000 ro@suse.de
- update to 2.4, cleanup spec
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jan 16 1997 maddin@suse.de
- first S.u.S.E. version 2.2
- changed paths
- copied documentation to /usr/doc/packages/procmtr
